diff --git a/include/hpp/manipulation/steering-method/cross-state-optimization.hh b/include/hpp/manipulation/steering-method/cross-state-optimization.hh
index 6563101556b3dd2a6c0b949430619b6fb83bf73c..cf040c1edf4d0d6919aaa2404345e3c38018a24e 100644
--- a/include/hpp/manipulation/steering-method/cross-state-optimization.hh
+++ b/include/hpp/manipulation/steering-method/cross-state-optimization.hh
@@ -23,7 +23,7 @@
 # include <hpp/manipulation/fwd.hh>
 # include <hpp/manipulation/problem.hh>
 # include <hpp/manipulation/steering-method/fwd.hh>
-# include <hpp/manipulation/graph-steering-method.hh>
+# include <hpp/manipulation/steering-method/graph.hh>
 
 namespace hpp {
   namespace manipulation {
diff --git a/src/graph/edge.cc b/src/graph/edge.cc
index 5c30efacb34c22d02160553f75547432a454bd73..537fd7e80259f17aff19bd50f258e40823be8c65 100644
--- a/src/graph/edge.cc
+++ b/src/graph/edge.cc
@@ -29,7 +29,7 @@
 
 #include "hpp/manipulation/device.hh"
 #include "hpp/manipulation/problem.hh"
-#include "hpp/manipulation/graph-steering-method.hh"
+#include "hpp/manipulation/steering-method/graph.hh"
 #include "hpp/manipulation/graph/statistics.hh"
 #include "hpp/manipulation/constraint-set.hh"
 
diff --git a/src/path-optimization/keypoints.cc b/src/path-optimization/keypoints.cc
index 384750c16389c4c7d43ea9d96e117a7bbefca9f2..fd802d0ef62e54127df5aded609f6685a245fdfe 100644
--- a/src/path-optimization/keypoints.cc
+++ b/src/path-optimization/keypoints.cc
@@ -24,7 +24,7 @@
 #include <hpp/manipulation/graph/edge.hh>
 #include <hpp/manipulation/graph/graph.hh>
 #include <hpp/manipulation/constraint-set.hh>
-#include <hpp/manipulation/graph-steering-method.hh>
+#include <hpp/manipulation/steering-method/graph.hh>
 
 namespace hpp {
   namespace manipulation {
diff --git a/src/problem.cc b/src/problem.cc
index 78a1b72cad15825c164815fb4ee90e9a14811d27..863604f0cf710d0132e6474dbccf9350f1e43e82 100644
--- a/src/problem.cc
+++ b/src/problem.cc
@@ -19,7 +19,7 @@
 #include <hpp/core/discretized-collision-checking.hh>
 
 #include <hpp/manipulation/weighed-distance.hh>
-#include <hpp/manipulation/graph-steering-method.hh>
+#include <hpp/manipulation/steering-method/graph.hh>
 #include <hpp/manipulation/graph-path-validation.hh>
 
 namespace hpp {
@@ -27,7 +27,7 @@ namespace hpp {
     Problem::Problem (DevicePtr_t robot)
       : Parent (robot), graph_()
     {
-      Parent::steeringMethod (GraphSteeringMethod::create (*this));
+      Parent::steeringMethod (steeringMethod::Graph::create (*this));
       distance (WeighedDistance::create (robot, graph_));
       setPathValidationFactory(core::DiscretizedCollisionChecking::create, 0.05);
diff --git a/include/hpp/manipulation/problem.hh b/include/hpp/manipulation/problem.hh
index c7c318b5db32f81ed8300fe833845b1ad5cda92a..5dce20faf52de7f2cb39858effb6ad6d919fcda9 100644
--- a/include/hpp/manipulation/problem.hh
+++ b/include/hpp/manipulation/problem.hh
@@ -55,7 +55,7 @@ namespace hpp {
           if (!pathValidation ())
             throw std::runtime_error ("No GraphPathValidation in the problem.");
           if (!steeringMethod ())
-            throw std::runtime_error ("No GraphSteeringMethod in the problem.");
+            throw std::runtime_error ("No SteeringMethod in the problem.");
         }
 
         /// Get the path validation as a GraphPathValidation
@@ -63,7 +63,7 @@ namespace hpp {
 
         void pathValidation (const PathValidationPtr_t& pathValidation);
 
         /// Get the steering method as a GraphSteeringMethod
         SteeringMethodPtr_t steeringMethod () const;
 
         /// Build a new path validation
@@ -63,7 +63,7 @@ namespace hpp {
         void pathValidation (const PathValidationPtr_t& pathValidation);
 
-        /// Get the steering method as a GraphSteeringMethod
+        /// Get the steering method as a SteeringMethod
         SteeringMethodPtr_t steeringMethod () const;
 